@@ -1,10 +1,11 @@
 SS_output <-
   function(dir="C:/myfiles/mymodels/myrun/", model="ss3",
            repfile="Report.sso", compfile="CompReport.sso",covarfile="covar.sso",
-           forefile="Forecast-report.sso",
-           ncols=200, forecast=TRUE, warn=TRUE, covar=TRUE,
+           forefile="Forecast-report.sso", wtfile="wtatage.ss_new",
+           ncols=200, forecast=TRUE, warn=TRUE, covar=TRUE, readwt=TRUE,
            checkcor=TRUE, cormax=0.95, cormin=0.01, printhighcor=10, printlowcor=10,
-           verbose=TRUE, printstats=TRUE,hidewarn=FALSE, NoCompOK=FALSE, aalmaxbinrange=4)
+           verbose=TRUE, printstats=TRUE,hidewarn=FALSE, NoCompOK=FALSE,
+           aalmaxbinrange=4)
 {
   ################################################################################
   #
@@ -17,23 +18,13 @@ SS_output <-
   #          and other contributors to http://code.google.com/p/r4ss/
   # Returns: a list containing elements of Report.sso and/or covar.sso,
   #          formatted as R objects, and optional summary statistics to R console
-  # Notes:   See users guide for documentation: http://code.google.com/p/r4ss/wiki/Documentation
-  # Required packages: none
   #
   ################################################################################
 
-  ## Ian T.: I've failed to reliably update the codedate variable,
-  ## perhaps this should be replaced with a check for a newer file version on the web
-  ## codedate <- "October 26, 2011"
-  if(verbose){
-    ## cat("R function updated:",codedate,"\n")
-    cat("Check for new code and report problems at http://code.google.com/p/r4ss/\n")
-  }
-
   flush.console()
 
   #################################################################################
-  ## embedded functions: matchfun and matchfun2
+  ## embedded functions: emptytest, matchfun and matchfun2
   #################################################################################
 
   emptytest <- function(x){ sum(!is.na(x) & x=="")/length(x) }
@@ -263,11 +254,30 @@ SS_output <-
       yielddat <- yielddat[order(yielddat$Depletion,decreasing = FALSE),]
     }
   }else{
-    if(verbose) cat("You skipped the forecast file\n",
-                    "setting sprtarg and btarg to 0.4 (can override in SS_plots)\n")
-    sprtarg <- 0.4
-    btarg <- 0.4
+    if(verbose)
+      cat("You skipped the forecast file\n",
+          "  setting SPR target and Biomass target to -999\n",
+          "  lines won't be drawn for these targets\n",
+          "  (can replace or override in SS_plots by setting 'sprtarg' and 'btarg')\n")
+    sprtarg <- -999
+    btarg <- -999
   }
+  minbthresh <- -999
+  if(!is.na(btarg) & btarg==0.4){
+    if(verbose)
+      cat("Setting minimum biomass threshhold to 0.25\n",
+          "  based on US west coast assumption associated with biomass target of 0.4.\n",
+          "  (can replace or override in SS_plots by setting 'minbthresh')\n")
+    minbthresh <- 0.25 # west coast assumption for non flatfish
+  }
+  if(!is.na(btarg) & btarg==0.25){
+    if(verbose)
+      cat("Setting minimum biomass threshhold to 0.25\n",
+          "  based on US west coast assumption associated with flatfish target of 0.25.\n",
+          "  (can replace or override in SS_plots by setting 'minbthresh')\n")
+    minbthresh <- 0.125 # west coast assumption for flatfish
+  }
+  
   flush.console()
 
   # check for use of temporary files
@@ -422,10 +432,17 @@ SS_output <-
 
       # starting with SSv3.24a, the Yr.S column is already in the output, otherwise fill it in
       if(!"Yr.S" %in% names(compdbase)){
-        # add fraction of season to distinguish between samples
-        compdbase$Yr.S <- compdbase$Yr + (0.5/nseasons)*compdbase$Seas
+        if(any(floor(compdbase$Yr)!=compdbase$Yr)){
+          # in some cases, year is already a decimal number
+          compdbase$Yr.S <- compdbase$Yr
+          compdbase$Yr <- floor(compdbase$Yr)
+        }else{
+          # add fraction of season to distinguish between samples
+          compdbase$Yr.S <- compdbase$Yr + (0.5/nseasons)*compdbase$Seas
+        }
       }
 
+
       # deal with Lbins
       compdbase$Lbin_range <- compdbase$Lbin_hi - compdbase$Lbin_lo
       compdbase$Lbin_mid <- 0.5*(compdbase$Lbin_lo + compdbase$Lbin_hi)
@@ -537,7 +554,7 @@ SS_output <-
     endcode <- "MOVEMENT"
     shift <- -2
   }
-  morph_indexing <- matchfun2("MORPH_INDEXING",1,endcode,shift,cols=1:9,header=T)
+  morph_indexing <- matchfun2("MORPH_INDEXING",1,endcode,shift,cols=1:9,header=TRUE)
   for(i in 1:ncol(morph_indexing)) morph_indexing[,i] <- as.numeric(morph_indexing[,i])
   ngpatterns <- max(morph_indexing$Gpattern)
 
@@ -734,6 +751,22 @@ SS_output <-
   }else{if(verbose) cat("You skipped the covar file\n")}
   flush.console()
 
+  # read weight-at-age file
+  wtatage <- NULL
+  if(readwt){
+    wtfile <- paste(dir,wtfile,sep="/")
+    if(!file.exists(wtfile) | file.info(wtfile)$size==0){
+      if(verbose) cat("Skipping weight-at-age file. File missing or empty:",wtfile,"\n")
+    }else{
+      # read top few lines to figure out how many to skip
+      wtatagelines <- readLines(wtfile,n=20)
+      # read full file
+      wtatage <- read.table(wtfile,header=TRUE,comment.char="",
+                            skip=(grep("yr seas gender",wtatagelines)-1))
+      names(wtatage)[1] <- "yr" # replacing "X.yr" created by presence of #
+    }
+  }
+  
   # derived quantities
   der <- matchfun2("DERIVED_QUANTITIES",4,"MGparm_By_Year_after_adjustments",-1,cols=1:3,header=TRUE)
   der[der=="_"] <- NA
@@ -1078,16 +1111,24 @@ if(FALSE){
     discard <- matchfun2("DISCARD_OUTPUT",shift,"MEAN_BODY_WT_OUTPUT",-1,header=FALSE)
     names(discard) <- c("Fleet","Yr","Seas","Obs","Exp","Std_in","Std_use","Dev")
   }
-
+  
   discard_type <- NA
   if(!is.na(discard) && nrow(discard)>1){
-    for(icol in 2:ncol(discard)) discard[,icol] <- as.numeric(discard[,icol])
-    for(i in 2:ncol(discard)) discard[,i] <- as.numeric(discard[,i])
-    discard$FleetName <- NA
-    discard$FleetNum <- NA
-    for(i in 1:nrow(discard)){
-      discard$FleetNum[i] <- strsplit(discard$Fleet[i],"_")[[1]][1]
-      discard$FleetName[i] <- substring(discard$Fleet[i],nchar(discard$FleetNum[i])+2)
+    discard[discard=="_"] <- NA
+    if(SS_versionNumeric <= 3.23){ # v3.23 and before had things combined under "name"
+      for(icol in (1:ncol(discard))[!(names(discard) %in% c("Fleet"))])
+        discard[,icol] <- as.numeric(discard[,icol])
+      discard$FleetNum <- NA
+      for(i in 1:nrow(discard)){
+        discard$FleetNum[i] <- strsplit(discard$Name[i],"_")[[1]][1]
+        discard$FleetName[i] <- substring(discard$Name[i],nchar(discard$FleetNum[i])+2)
+      }
+    }else{ # v3.24 and beyond has separate columns for fleet number and fleet name
+      for(icol in (1:ncol(discard))[!(names(discard) %in% c("Name","SuprPer"))])
+        discard[,icol] <- as.numeric(discard[,icol])
+      # redundant columns are holdovers from earlier SS versions
+      discard$FleetNum <- discard$Fleet
+      discard$FleetName <- discard$Name
     }
   }else{
     discard <- NA
@@ -1103,15 +1144,23 @@ if(FALSE){
   DF_mnwgt <- rawrep[matchfun("log(L)_based_on_T_distribution"),1]
   if(!is.na(DF_mnwgt)){
     DF_mnwgt <- as.numeric(strsplit(DF_mnwgt,"=_")[[1]][2])
-    mnwgt <- matchfun2("MEAN_BODY_WT_OUTPUT",2,"FIT_LEN_COMPS",-1,cols=1:10,header=TRUE)
-    if(nrow(mnwgt)>0){
-      for(i in 2:ncol(mnwgt)) mnwgt[,i] <- as.numeric(mnwgt[,i])
-      mnwgt$FleetName <- NA
+    mnwgt <- matchfun2("MEAN_BODY_WT_OUTPUT",2,"FIT_LEN_COMPS",-1,header=TRUE)
+
+    mnwgt[mnwgt=="_"] <- NA
+    if(SS_versionNumeric <= 3.23){ # v3.23 and before had things combined under "name"
+      for(icol in (1:ncol(mnwgt))[!(names(mnwgt) %in% c("Fleet"))])
+        mnwgt[,icol] <- as.numeric(mnwgt[,icol])
       mnwgt$FleetNum <- NA
       for(i in 1:nrow(mnwgt)){
         mnwgt$FleetNum[i] <- strsplit(mnwgt$Fleet[i],"_")[[1]][1]
         mnwgt$FleetName[i] <- substring(mnwgt$Fleet[i],nchar(mnwgt$FleetNum[i])+2)
       }
+    }else{ # v3.24 and beyond has separate columns for fleet number and fleet name
+      for(icol in (1:ncol(mnwgt))[!(names(mnwgt) %in% c("Name"))])
+        mnwgt[,icol] <- as.numeric(mnwgt[,icol])
+      # redundant columns are holdovers from earlier SS versions
+      mnwgt$FleetNum <- mnwgt$Fleet
+      mnwgt$FleetName <- mnwgt$Name
     }
   }else{
     DF_mnwgt <- NA
@@ -1154,7 +1203,7 @@ if(FALSE){
   returndat$B_ratio_denominator <- as.numeric(strsplit(managementratiolabels$Label[3],"%")[[1]][1])/100
   returndat$sprtarg <- sprtarg
   returndat$btarg <- btarg
-  returndat$minbthresh <- ifelse(btarg==0.25,0.125,0.25)
+  returndat$minbthresh <- minbthresh
 
 
   # Spawner-recruit curve
@@ -1435,6 +1484,9 @@ if(FALSE){
   RecrDistpars <- parameters[substring(parameters$Label,1,8)=="RecrDist",]
   returndat$RecrDistpars <- RecrDistpars
 
+  # adding read of wtatage file
+  returndat$wtatage <- wtatage
+
   # print list of statistics
   if(printstats){
     cat("Statistics shown below (to turn off, change input to printstats=FALSE)\n")
