@@ -1,7 +1,8 @@
 SSplotMovementMap <-
   function(replist=NULL, xlim, ylim,
            polygonlist, colvec, land="grey", xytable=NULL,
-           moveage=5,moveseas=1,lwdscale=5,legend=TRUE,title=NULL)
+           moveage=5,moveseas=1,lwdscale=5,legend=TRUE,title=NULL,
+           areanames=NULL,cex=1)
 {
   # plot movement rates on map to help visualize patterns
   # note: requires R package "maps"
@@ -82,6 +83,7 @@ SSplotMovementMap <-
                round(100*max(ratevec),3),"%",sep=""))
     }
   }
+  if(!is.null(areanames) & !is.null(areanames)) text(xytable,areanames,cex=cex)
 }
 
   
